Index: src/bootstrapper.cc |
diff --git a/src/bootstrapper.cc b/src/bootstrapper.cc |
index 0466e3113dc51e357e653783834e9c82b6df4c41..22c75a1aeb50c6abe00cab33c9b2b89c2febaaef 100644 |
--- a/src/bootstrapper.cc |
+++ b/src/bootstrapper.cc |
@@ -1240,8 +1240,9 @@ bool Genesis::InitializeGlobal(Handle<GlobalObject> inner_global, |
// Initialize the out of memory slot. |
native_context()->set_out_of_memory(heap->false_value()); |
- // Initialize the data slot. |
- native_context()->set_data(heap->undefined_value()); |
+ // Initialize the embedder data slot. |
+ Handle<FixedArray> embedder_data = factory->NewFixedArray(2); |
+ native_context()->set_embedder_data(*embedder_data); |
{ |
// Initialize the random seed slot. |